@@ -176,6 +176,8 @@ def set_idemailstatus_target_column(df):
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
         df.loc[df['IDEmailStatus'] != 14, 'IDEmailStatus'] = 0
         df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
+        status_col = df.pop( 'IDEmailStatus')
+        df.insert(0, status_col, 'IDEmailStatus')
     else:
         logger.error('No IDEmailSTatus column found')
         raise Exception('No IDEmailStatus column found!!!!!')
@@ -187,6 +189,8 @@ def set_bv_target_column(df):
         logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
         df['BV']=df['BV'].astype('float32')
+        bv_col = df.pop( 'BV')
+        df.insert(0, bv_col, 'BV')
     else:
         logger.error('No BV column found')
         raise Exception('No BV column found!!!!!')
